@@ -4,7 +4,8 @@ from .augment import *
 from .learner import *
 from .mixup import *
 from ..basics import *
-from ..callback import channelslast, lr_finder
+from ..callback import channelslast, lr_finder, tracker
+from ..data.all import *
 from ..losses import *
 from ..metrics import *
 from ..multiloss import *
